use std::{
    fs::{self},
    path::PathBuf,
    time::Instant,
};

use binrw::{BinRead, BinWriterExt};
use clap::Parser;
use ezcad::file::Header;
use log::info;

#[derive(Debug, Parser)]
struct Cli {
    /// Input file to parse
    #[arg(short, long)]
    input: PathBuf,

    /// Output file to write to
    #[arg(short, long)]
    output: Option<PathBuf>,

    // /// Configuration file
    // #[arg(short, long)]
    // config: PathBuf,
    #[command(flatten)]
    verbose: clap_verbosity_flag::Verbosity,
}

fn main() {
    env_logger::builder()
        .format_timestamp(None)
        .filter_level(log::LevelFilter::Info)
        .init();

    let args: Cli = Cli::parse();

    let mut input = fs::File::open(args.input).unwrap();
    // let _config = read(args.config).unwrap();

    let time = Instant::now();

    let file = Header::read_le(&mut input).unwrap();

    info!("Execution time: {:?}", time.elapsed());

    for pen in file.pens_offset.data.pens.iter().take(1) {
        dbg!(pen);
    }

    for layer in file.layers_offset.iter() {
        for object in layer.objects.iter() {
            dbg!(object);
        }
    }

    if let Some(output) = args.output {
        let mut output = fs::File::create(output).unwrap();
        output.write_le(&file).unwrap();
    }
}
